@@ -12,6 +12,7 @@ namespace OCA\Bookmarks\Controller\Rest;
 
 use OCP\IDBConnection;
 use OCP\IL10N;
+use OCP\ILogger;
 use \OCP\IRequest;
 use \OCP\AppFramework\ApiController;
 use \OCP\AppFramework\Http\DataDisplayResponse;
@@ -47,10 +48,11 @@ class InternalBookmarkController extends ApiController {
 		IPreviewService $previewService,
 		IPreviewService $faviconService,
 		IPreviewService $screenshotService,
-		ITimeFactory $timeFactory
+		ITimeFactory $timeFactory,
+		ILogger $logger
 	) {
 		parent::__construct($appName, $request);
-		$this->publicController = new BookmarkController($appName, $request, $userId, $db, $l10n, $bookmarks, $userManager);
+		$this->publicController = new BookmarkController($appName, $request, $userId, $db, $l10n, $bookmarks, $userManager, $logger);
 		$this->userId = $userId;
 		$this->libBookmarks = $bookmarks;
 		$this->previewService = $previewService;
@@ -86,9 +88,10 @@ class InternalBookmarkController extends ApiController {
 		$sortby = "",
 		$search = [],
 		$limit = 10,
-		$untagged = false
+		$untagged = false,
+		$folder = null
 	) {
-		return $this->publicController->getBookmarks($type, $tag, $page, $sort, $user, $tags, $conjunction, $sortby, $search, $limit, $untagged);
+		return $this->publicController->getBookmarks($type, $tag, $page, $sort, $user, $tags, $conjunction, $sortby, $search, $limit, $untagged, $folder);
 	}
 
 	/**
@@ -145,8 +148,8 @@ class InternalBookmarkController extends ApiController {
 	 *
 	 * @NoAdminRequired
 	 */
-	public function editBookmark($id = null, $url = "", $item = [], $title = "", $is_public = false, $record_id = null, $description = "", $tags = []) {
-		return $this->publicController->editBookmark($id, $url, $item, $title, $is_public, $record_id, $description, $tags);
+	public function editBookmark($id = null, $url = "", $item = [], $title = "", $is_public = false, $record_id = null, $description = "", $tags = [], $folders = null) {
+		return $this->publicController->editBookmark($id, $url, $item, $title, $is_public, $record_id, $description, $tags, $folders);
 	}
 
 	/**
