@@ -3,7 +3,6 @@ OC.L10N.register(
     {
     "Bookmarks" : "Σελιδοδείκτες",
     "Failed to import one bookmark, because: " : "Αποτυχία εισαγωγής ενός σελιδοδείκτη, επειδή:",
-    "Bookm." : "Σελιδοδήκτης",
     "No file provided for import" : "Δεν δόθηκε αρχείο για εισαγωγή",
     "Unsupported file type for import" : "Μη υποστηριζόμενος τύπος αρχείου",
     "Add a Bookmark" : "Προσθήκη σελιδοδείκτη",
@@ -15,19 +14,13 @@ OC.L10N.register(
     "Tags" : "Ετικέτες",
     "Description" : "Περιγραφή",
     "No bookmarks here." : "Δεν υπάρχουν σελιδοδείκτες εδώ",
-    "All bookmarks" : "Όλοι οι σελιδοδείκτες",
-    "Untagged" : "Χωρίς ετικέτα",
-    "Shared" : "Κοινόχρηστα",
     "Settings" : "Ρυθμίσεις",
     "Add to {instanceName} " : "Προσθήκη στο {instanceName} ",
     "Recently added" : "Προστέθηκαν πρόσφατα",
     "RSS Feed" : "Ροή RSS",
-    "Add to filter" : "Προσθήκη στο φίλτρο",
-    "Rename" : "Μετονομασία",
     "Open details" : "Άνοιγμα λεπτομερειών",
     "An error occurred while trying to save the bookmark." : "Παρουσιάστηκε σφάλμα κατά την αποθήκευση του σελιδοδείκτη",
     "Error" : "Σφάλμα",
-    "Uploading..." : "Γίνεται μεταφόρτωση...",
     "Import error" : "Σφάλμα εισαγωγής",
     "Set tags" : "Ορισμός ετικετών",
     "Add a bookmark" : "Προσθήκη σελιδοδείκτη",
