@@ -3,10 +3,10 @@ OC.L10N.register(
     {
     "Bookmarks" : "Marcadores",
     "Failed to import one bookmark, because: " : "Error al importar un marcador a causa de:",
-    "Bookm." : "Marcad.",
     "No file provided for import" : "No se seleccionó un archivo para importar",
     "Unsupported file type for import" : "Tipo de archivo no soportado",
     "Add a Bookmark" : "Añadir un marcador",
+    "Add folder" : "Añadir carpeta",
     "Select" : "Seleccionar",
     "Deselect" : "Deseleccionar",
     "Details" : "Detalles",
@@ -15,9 +15,7 @@ OC.L10N.register(
     "Tags" : "Etiquetas",
     "Description" : "Descripción",
     "No bookmarks here." : "No hay marcadores aquí.",
-    "All bookmarks" : "Todos los marcadores",
-    "Untagged" : "Sin etiquetas",
-    "Shared" : "Compartidos",
+    "Favorites" : "Favoritos",
     "Settings" : "Configuración",
     "Bookmarklet" : "Bookmarklet",
     "Add to {instanceName} " : "Añadir a {instanceName}",
@@ -26,13 +24,10 @@ OC.L10N.register(
     "RSS Feed" : "Fuente RSS",
     "Permanently remove all bookmarks from your account. There is no going back!" : "Eliminar permanentemente todos los marcadores de tu cuenta. ¡No hay vuelta atrás!",
     "Delete all bookmarks" : "Eliminar todos los marcadores",
-    "Add to filter" : "Añadir al filtro",
-    "Remove from filter" : "Eliminar del filtro",
-    "Rename" : "Renombrar",
     "Open details" : "Abrir detalles",
     "An error occurred while trying to save the bookmark." : "Se ha producido un error al intentar guardar el marcador.",
     "Error" : "Error",
-    "Uploading..." : "Subiendo...",
+    "Uncategorized" : "Sin categoría",
     "Import error" : "Error de importación",
     "Import completed successfully." : "Importación completada con éxito.",
     "Set tags" : "Poner etiquetas",
