@@ -3,7 +3,6 @@ OC.L10N.register(
     {
     "Bookmarks" : "Marcadores",
     "Failed to import one bookmark, because: " : "Se presentó una falla al importar un marcador debido a:",
-    "Bookm." : "Marcdr.",
     "No file provided for import" : "No se especificó un archivo para importar",
     "Unsupported file type for import" : "Tipo de archivo no soportado para importar",
     "Add a Bookmark" : "Agregar un Marcador",
@@ -13,17 +12,11 @@ OC.L10N.register(
     "Delete" : "Borrar",
     "Saved" : "Guardado",
     "No bookmarks here." : "No hay marcadores aquí.",
-    "All bookmarks" : "Todos los marcadores",
-    "Shared" : "Compartido",
     "Settings" : "Configuraciones",
     "Bookmarklet" : "Marcador a código ",
     "Add to {instanceName} " : "Agregar a {instanceName}",
-    "Add to filter" : "Agregar al filtro",
-    "Remove from filter" : "Eliminar del filtro",
-    "Rename" : "Renombrar",
     "An error occurred while trying to save the bookmark." : "Se presentó un error al intentar guardar el marcador. ",
     "Error" : "Error",
-    "Uploading..." : "Cargando...",
     "Import error" : "Error al importar",
     "Import completed successfully." : "El importar terminón exitosamente.",
     "Set tags" : "Establecer etiquetas",
