@@ -6,6 +6,7 @@ OC.L10N.register(
     "No file provided for import" : "Tuotavaa tiedostoa ei ole valittu",
     "Unsupported file type for import" : "Tiedoston tyyppi ei ole tuotavaa muotoa",
     "Add a Bookmark" : "Lisää kirjanmerkki",
+    "Add folder" : "Lisää kansio",
     "Select" : "Valitse",
     "Deselect" : "Ei valintaa",
     "Details" : "Tiedot",
@@ -14,6 +15,7 @@ OC.L10N.register(
     "Tags" : "Tunnisteet",
     "Description" : "Kuvaus",
     "No bookmarks here." : "Täällä ei ole kirjanmerkkejä.",
+    "Favorites" : "Suosikit",
     "Settings" : "Asetukset",
     "Recently added" : "Äskettäin lisätty",
     "Most visited" : "Vierailuimmat",
@@ -23,6 +25,7 @@ OC.L10N.register(
     "Open details" : "Avaa yksityiskohdat",
     "An error occurred while trying to save the bookmark." : "Kirjanmerkin tallennusta yrittäessä tapahtui virhe.",
     "Error" : "Virhe",
+    "Uncategorized" : "Luokittelematon",
     "Import error" : "Tuontivirhe",
     "Import completed successfully." : "Tuonti suoritettiin onnistuneesti.",
     "Set tags" : "Aseta tunnisteet",
