@@ -3,10 +3,10 @@ OC.L10N.register(
     {
     "Bookmarks" : "Favoris",
     "Failed to import one bookmark, because: " : "Impossible d'importer un favori",
-    "Bookm." : "Favoris",
     "No file provided for import" : "Aucun fichier à importer.",
     "Unsupported file type for import" : "Type de fichier non supporté",
     "Add a Bookmark" : "Ajouter un favori",
+    "Add folder" : "Ajouter un dossier",
     "Select" : "Sélectionner",
     "Deselect" : "Désélectionner",
     "Details" : "Propriétés",
@@ -15,9 +15,7 @@ OC.L10N.register(
     "Tags" : "Étiquettes",
     "Description" : "Description",
     "No bookmarks here." : "Pas de favoris ici.",
-    "All bookmarks" : "Tous les favoris",
-    "Untagged" : "Non étiqueté",
-    "Shared" : "Partagé",
+    "Favorites" : "Favoris",
     "Settings" : "Paramètres",
     "Bookmarklet" : "Favelets",
     "Add to {instanceName} " : "Ajouter à {instanceName}",
@@ -26,13 +24,10 @@ OC.L10N.register(
     "RSS Feed" : "Flux RSS",
     "Permanently remove all bookmarks from your account. There is no going back!" : "Supprimer de manière définitive tous les favoris de votre compte. Il n'y a aucun moyen de revenir en arrière !",
     "Delete all bookmarks" : "Supprimer tous les favoris",
-    "Add to filter" : "Ajouter au filtre",
-    "Remove from filter" : "Supprimer du filtre",
-    "Rename" : "Renommer",
     "Open details" : "Ouvrir les détails",
     "An error occurred while trying to save the bookmark." : "Une erreur est survenue lors de la sauvegarde du marque-page.",
     "Error" : "Erreur",
-    "Uploading..." : "Envoi en cours…",
+    "Uncategorized" : "Non catégorisé",
     "Import error" : "Erreur d'importation",
     "Import completed successfully." : "Importation terminée avec succès.",
     "Set tags" : "Choisir des étiquettes",
