@@ -3,7 +3,6 @@ OC.L10N.register(
     {
     "Bookmarks" : "סימניות",
     "Failed to import one bookmark, because: " : "הייבוא של אחת מהסימניות נכשל, הסיבה:",
-    "Bookm." : "סימנ.",
     "No file provided for import" : "לא סופק קובץ לייבוא",
     "Unsupported file type for import" : "סוג הקובץ לייבוא אינו נתמך",
     "Add a Bookmark" : "הוספת סימנייה",
@@ -15,9 +14,6 @@ OC.L10N.register(
     "Tags" : "תגיות",
     "Description" : "תיאור",
     "No bookmarks here." : "אין כאן סימניות.",
-    "All bookmarks" : "כל הסימניות",
-    "Untagged" : "ללא תגית",
-    "Shared" : "משותפת",
     "Settings" : "הגדרות",
     "Bookmarklet" : "יישומון סימנייה",
     "Add to {instanceName} " : "הוספה אל {instanceName} ",
@@ -26,13 +22,9 @@ OC.L10N.register(
     "RSS Feed" : "ערוץ RSS",
     "Permanently remove all bookmarks from your account. There is no going back!" : "הסרת כל הסימניות מהחשבון שלך לצמיתות. אי אפשר לחזור אחורה!",
     "Delete all bookmarks" : "מחיקת כל הסימניות",
-    "Add to filter" : "הוספה למסנן",
-    "Remove from filter" : "הסרה ממסנן",
-    "Rename" : "שינוי שם",
     "Open details" : "פתיחת פרטים",
     "An error occurred while trying to save the bookmark." : "אירעה שגיאה בעת הניסיון לשמור סימניה.",
     "Error" : "שגיאה",
-    "Uploading..." : "מתבצעת העלאה…",
     "Import error" : "שגיאת ייבוא",
     "Import completed successfully." : "הייבוא הושלם בהצלחה.",
     "Set tags" : "הגדרת תגיות",
