@@ -3,10 +3,10 @@ OC.L10N.register(
     {
     "Bookmarks" : "Könyvjelzők",
     "Failed to import one bookmark, because: " : "Nem sikerült egy könyvjelző betöltése, mert:",
-    "Bookm." : "Könyvj.",
     "No file provided for import" : "Nincs fájl megadva importáláshoz",
     "Unsupported file type for import" : "Nem támogatott fájltípus az importáláshoz",
     "Add a Bookmark" : "Könyvjelző hozzáadása",
+    "Add folder" : "Mappa hozzáadás",
     "Select" : "Kijelöl",
     "Deselect" : "Kijelölés megszűntetése",
     "Details" : "Részletek",
@@ -15,24 +15,19 @@ OC.L10N.register(
     "Tags" : "Cimkék",
     "Description" : "Leírás",
     "No bookmarks here." : "Nincsenek könyvjelzők.",
-    "All bookmarks" : "Minden könyvjelző",
-    "Untagged" : "Nem cimkézett",
-    "Shared" : "Megosztva",
+    "Favorites" : "Kedvencek",
     "Settings" : "Beállítások",
     "Bookmarklet" : "Bookmarklet",
     "Add to {instanceName} " : "Hozzáadás a következőhöz: {instanceName}",
     "Recently added" : "Utoljára hozzáadva",
     "Most visited" : "Legtöbbet látogatva",
-    "RSS Feed" : "RSS folyam",
+    "RSS Feed" : "RSS-csatorna",
     "Permanently remove all bookmarks from your account. There is no going back!" : "Véglegesen törlöd az összes könyvjelzőt a fiókodból! Nincs visszaút!",
     "Delete all bookmarks" : "Összes könyvjelzők törlése",
-    "Add to filter" : "Hozzáadás szűrőhöz",
-    "Remove from filter" : "Eltávolítás a szűrőből",
-    "Rename" : "Átnevezés",
     "Open details" : "Részletek megjelenítése",
     "An error occurred while trying to save the bookmark." : "Hiba történt a könyvjelző mentése közben.",
     "Error" : "Hiba",
-    "Uploading..." : "Frissítés...",
+    "Uncategorized" : "Kategorizálatlan",
     "Import error" : "Importálási hiba",
     "Import completed successfully." : "Sikeres importálás.",
     "Set tags" : "Cimke beállítás",
@@ -40,7 +35,7 @@ OC.L10N.register(
     "This app allows you to store and organize your favorite places on the web in one spot, while allowing you to sync them with your various devices and browsers.\nCheck out the third-party clients listed here: https://github.com/nextcloud/bookmarks#third-party-clients" : "Ez az alkalmazás lehetővé teszi, hogy kedvenc helyeit egy központi helyen tárolja és rendezze, miközben biztosítja a különböző eszközökkel és böngészőkkel való szinkronizálást.\n\nNézze meg a harmadik féltől származó klienseket: https://github.com/nextcloud/bookmarks#third-party-clients",
     "Add a bookmark" : "Könyvjelző hozzáadása",
     "This URL is already bookmarked! Overwrite?" : "Ez a cím már jegyezve van. Felülírod?",
-    "The title of the page" : "Az oldal tárgya",
+    "The title of the page" : "Az oldal címe",
     "The address of the page" : "Az oldal címe",
     "Description of the page" : "Az oldal leírása",
     "Save" : "Mentés",
