@@ -3,10 +3,10 @@ OC.L10N.register(
     {
     "Bookmarks" : "Bókamerki",
     "Failed to import one bookmark, because: " : "Mistókst að flytja inn bókamerki, vegna: ",
-    "Bookm." : "Bókam.",
     "No file provided for import" : "Engin skrá valin til innflutnings",
     "Unsupported file type for import" : "Ekki er hægt að flytja inn þessa tegund af bókamerki",
     "Add a Bookmark" : "Bæta við bókamerki",
+    "Add folder" : "Bæta við möppu",
     "Select" : "Velja",
     "Deselect" : "Afvelja",
     "Details" : "Nánar",
@@ -15,22 +15,19 @@ OC.L10N.register(
     "Tags" : "Merki",
     "Description" : "Lýsing",
     "No bookmarks here." : "Engin bókamerki hér.",
-    "All bookmarks" : "Öll bókamerki",
-    "Untagged" : "Ómerkt",
-    "Shared" : "Deilt",
+    "Favorites" : "Eftirlæti",
     "Settings" : "Stillingar",
     "Bookmarklet" : "Bókamerklingur",
     "Add to {instanceName} " : "Bæta við {instanceName} ",
     "Recently added" : "Nýlega bætt við",
     "Most visited" : "Mest heimsótt",
+    "RSS Feed" : "RSS streymi",
+    "Permanently remove all bookmarks from your account. There is no going back!" : "Eyddu varanlega öllum bókamerkjum úr aðgangnum þínum. Ekki er hægt að afturkalla þetta!",
     "Delete all bookmarks" : "Eyða öllum bókamerkjum",
-    "Add to filter" : "Bæta við síu",
-    "Remove from filter" : "Fjarlægja úr síu",
-    "Rename" : "Endurnefna",
     "Open details" : "Opna nánari upplýsingar",
     "An error occurred while trying to save the bookmark." : "Villa kom upp við að reyna að vista bókamerkið.",
     "Error" : "Villa",
-    "Uploading..." : "Sendi inn ...",
+    "Uncategorized" : "Óflokkað",
     "Import error" : "Villa í innflutningi",
     "Import completed successfully." : "Tókst að flytja inn.",
     "Set tags" : "Stilla merki",
@@ -46,6 +43,7 @@ OC.L10N.register(
     "In order to display real screenshots of your bookmarked websites, Bookmarks can use a third-party service to generate those." : "Til þess að birta raunverulegar skjámyndir af þeim vefsíðum sem þú bókamerkir, getur bókamerkjaforritið notað þjónustu utanaðkomandi aðila til að útbúa skjámyndirnar.",
     "You can either sign up for free at <a href=\"http://screeenly.com\">screeenly.com</a> or <a href=\"https://github.com/stefanzweifel/screeenly\">setup your own server</a>." : "Þú getur annað hvort skráð þig ókeypis á <a href=\"http://screeenly.com\">screeenly.com</a> eða <a href=\"https://github.com/stefanzweifel/screeenly\">sett upp þinn eigin þjón</a>.",
     "Screenly API URL" : "Slóð á API-forritsviðmót Screenly",
-    "Screenly API key" : "Lykill á API-forritsviðmót Screenly"
+    "Screenly API key" : "Lykill á API-forritsviðmót Screenly",
+    "Bookmarks feed" : "Bókamerkjastreymi"
 },
 "nplurals=2; plural=(n % 10 != 1 || n % 100 == 11);");
