@@ -3,14 +3,12 @@ OC.L10N.register(
     {
     "Bookmarks" : "Bokmerker",
     "Failed to import one bookmark, because: " : "Klarte ikke importere et bokmerke, fordi:",
-    "Bookm." : "Bokmerk",
     "No file provided for import" : "Ingen fil valgt for import",
     "Unsupported file type for import" : "Usupportert filtype for import",
     "Select" : "Velg",
     "Deselect" : "Fjern markering",
     "An error occurred while trying to save the bookmark." : "En feil inntraff under forsøk på å lagre bokmerket.",
     "Error" : "Feil",
-    "Uploading..." : "Laster opp …",
     "Import error" : "Feil under importering",
     "Import completed successfully." : "Importering fullført uten feil",
     "Set tags" : "Sett merkelapper",
