@@ -3,10 +3,10 @@ OC.L10N.register(
     {
     "Bookmarks" : "Закладки",
     "Failed to import one bookmark, because: " : "Не удалось импортировать одну закладку, потому, что:",
-    "Bookm." : "Заклд.",
     "No file provided for import" : "Не указан файл для импорта",
     "Unsupported file type for import" : "Неподдерживаемый тип файла для импорта",
     "Add a Bookmark" : "Добавить закладку",
+    "Add folder" : "Добавить каталог",
     "Select" : "Пометить",
     "Deselect" : "Снять пометку",
     "Details" : "Подробно",
@@ -15,9 +15,7 @@ OC.L10N.register(
     "Tags" : "Метки",
     "Description" : "Описание",
     "No bookmarks here." : "Нет закладок",
-    "All bookmarks" : "Все закладки",
-    "Untagged" : "Без меток",
-    "Shared" : "Поделиться",
+    "Favorites" : "Избранное",
     "Settings" : "Настройки",
     "Bookmarklet" : "Приложение для панели закладок",
     "Add to {instanceName} " : "Добавить в {instanceName} ",
@@ -26,13 +24,10 @@ OC.L10N.register(
     "RSS Feed" : "RSS-лента",
     "Permanently remove all bookmarks from your account. There is no going back!" : "Окончательное удаление всех закладок без возможности восстановления.",
     "Delete all bookmarks" : "Удалить все закладки",
-    "Add to filter" : "Добавить в фильтр",
-    "Remove from filter" : "Удалить из фильтра",
-    "Rename" : "Переименовать",
     "Open details" : "Открыть подробности",
     "An error occurred while trying to save the bookmark." : "Не удалось сохранить закладку.",
     "Error" : "Ошибка",
-    "Uploading..." : "Идет загрузка…",
+    "Uncategorized" : "Без категории",
     "Import error" : "Ошибка импорта",
     "Import completed successfully." : "Успешное завершение импорта.",
     "Set tags" : "Задать метки",
